pub fn load_credentials() -> Result<CredentialStore>Expand description
Load the credential store from disk. Returns an empty store if the file does not exist.
pub fn load_credentials() -> Result<CredentialStore>Load the credential store from disk. Returns an empty store if the file does not exist.